@@ -4,13 +4,13 @@ from ..MuviBase import MuviBase
 
 card_brand = {
     1: 'Visa',
-    8: 'Diners Club',
+    8: 'Diners',
     23: 'Tarjeta Shopping',
     24: 'Tarjeta Naranja',
-    25: 'PagoFacil',
-    26: 'RapiPago',
+    25: 'Pago Fácil',
+    26: 'Rapipago',
     29: 'Italcred',
-    30: 'ArgenCard',
+    30: 'Argencard',
     34: 'CoopePlus',
     37: 'Nexo',
     38: 'Credimás',
@@ -30,26 +30,26 @@ card_brand = {
     60: 'Distribution',
     61: 'Tarjeta La Anónima',
     62: 'CrediGuia',
-    63: 'Cabal Prisma',
+    63: 'Cabal',
     64: 'Tarjeta SOL',
     65: 'American Express',
     103: 'Favacard',
-    104: 'MasterCard Prisma',
+    104: 'Mastercard',
     109: 'Nativa Prisma',
     111: 'American Express Prisma',
     
     # Debito
     31: 'Visa Débito',
-    105: 'MasterCard Debit Prisma',
-    106: 'Maestro Prisma',
-    108: 'Cabal Débito Prisma'
+    105: 'Mastercard Débito',
+    106: 'Maestro',
+    108: 'Cabal Débito'
 }
 
 
 def _card_type(payment_method_id):
     if payment_method_id in [31, 105, 106, 108]:
-        return 'credit_card'
-    return 'debit_card'
+        return 'debit_card'
+    return 'credit_card'
 
 
 def _format(response, customer_id):
@@ -64,8 +64,8 @@ def _format(response, customer_id):
         'cardholder': {
             'name': response['card_holder']['name']
         },
-        'expiration_month': response['expiration_month'],
-        'expiration_year': response['expiration_year'],
+        'expiration_month': int(response['expiration_month']),
+        'expiration_year': int('20' + response['expiration_year']),
     }
 
 
@@ -98,7 +98,12 @@ class Card(MuviBase):
 
     def get(self, customer_id: str, card_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
-        cards = r.json()['tokens']
+        response = r.json()
+        
+        if 'tokens' not in response:
+            return self.error(message=response['message'])
+        
+        cards = response['tokens']
 
         for card in cards:
             if card['token'] == card_id:
@@ -107,5 +112,8 @@ class Card(MuviBase):
 
     def list_all(self, customer_id: str):
         r = requests.get('{}/usersite/{}/cardtokens'.format(self.url, customer_id), headers=self.headers)
-        cards = r.json()['tokens']
+        response = r.json()
+        if 'tokens' not in response:
+            return self.error(message='customer not found')
+        cards = response['tokens']
         return self.ok(response={'results': [_format(card, customer_id) for card in cards]}, status=r.status_code)
