@@ -19,7 +19,7 @@ class CardToken(MuviBase):
             card_token_response = self.sdk.card_token().create(data)
         except:
             return self.error(
-                response='error_cant_create_token',
+                message='error_cant_create_token',
                 status=400
             )
         if card_token_response['status'] > 299:
