@@ -13,10 +13,11 @@ class MercadoPagoSDK:
             active = merchant['credentials']['mercadopago']['active']
             access_token = merchant['credentials']['mercadopago']['access_token'] if active else None
         elif 'credentials' in merchant and 'mp_marketplace' in merchant['credentials'] and marketplace:
-            active = merchant['credentials']['mp_marketplace']['active']
+            active = 'mp_marketplace' in merchant['credentials'] and \
+                     ('active' not in merchant['credentials']['mp_marketplace'] or
+                      merchant['credentials']['mp_marketplace']['active'])
             access_token = merchant['credentials']['mp_marketplace']['access_token'] if active else None
-        else:
-            access_token = merchant['keys_marketplace']['access_token'] if marketplace else merchant['keys']['access_token']
+
         self.sdk = mercadopago.SDK(access_token) if active else None
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
