@@ -43,7 +43,7 @@ def _format_card(response):
 def _format(response):
     response['payment_method'] = response['payment_method_id']
     if response['payment_method_id'] in card_brand_map:
-        response['payment_method_id'] = str(card_brand_map[response['payment_method_id']])
+        response['payment_method_id'] = card_brand_map[response['payment_method_id']]
 
     return {
         'id': response['id'],
